@@ -9,7 +9,7 @@
 #' cluster memberships for new data.
 #'
 #' @templateVar id clust.dbscan
-#' @template section_dictionary_learner
+#' @template learner
 #' @template example
 #'
 #' @export
@@ -19,28 +19,21 @@ LearnerClustDBSCAN = R6Class("LearnerClustDBSCAN",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ParamSet$new(
-        params = list(
-          ParamDbl$new(id = "eps", lower = 0L, tags = c("required", "train")),
-          ParamInt$new(id = "minPts", lower = 0L, default = 5L, tags = "train"),
-          ParamLgl$new(id = "borderPoints", default = TRUE, tags = "train"),
-          ParamUty$new(id = "weights", custom_check = function(x) {
-            if (test_numeric(x)) {
-              return(TRUE)
-            } else {
-              stop("`weights` need to be a numeric vector")
-            }
-          }, tags = "train"),
-          ParamFct$new(
-            id = "search", levels = c("kdtree", "linear", "dist"),
-            default = "kdtree", tags = "train"),
-          ParamInt$new(id = "bucketSize", lower = 1L, default = 10L, tags = "train"),
-          ParamFct$new(
-            id = "splitRule",
-            levels = c("STD", "MIDPT", "FAIR", "SL_MIDPT", "SL_FAIR", "SUGGEST"),
-            default = "SUGGEST", tags = "train"),
-          ParamDbl$new(id = "approx", default = 0L, tags = "train")
-        )
+      ps = ps(
+        eps = p_dbl(lower = 0L, tags = c("required", "train")),
+        minPts = p_int(lower = 0L, default = 5L, tags = "train"),
+        borderPoints = p_lgl(default = TRUE, tags = "train"),
+        weights = p_uty(custom_check = function(x) {
+          if (test_numeric(x)) {
+            return(TRUE)
+          } else {
+            stop("`weights` need to be a numeric vector")
+          }
+        }, tags = "train"),
+        search = p_fct(levels = c("kdtree", "linear", "dist"), default = "kdtree", tags = "train"),
+        bucketSize = p_int(lower = 1L, default = 10L, tags = "train"),
+        splitRule = p_fct(levels = c("STD", "MIDPT", "FAIR", "SL_MIDPT", "SL_FAIR", "SUGGEST"), default = "SUGGEST", tags = "train"),
+        approx = p_dbl(default = 0L, tags = "train")
       )
       # add deps
       ps$add_dep("bucketSize", "search", CondEqual$new("kdtree"))
@@ -52,7 +45,8 @@ LearnerClustDBSCAN = R6Class("LearnerClustDBSCAN",
         predict_types = "partition",
         param_set = ps,
         properties = c("partitional", "exclusive", "complete"),
-        packages = "dbscan"
+        packages = "dbscan",
+        label = "Density-Based Clustering"
       )
     }
   ),
