@@ -10,7 +10,7 @@
 #' cluster memberships for new data.
 #'
 #' @templateVar id clust.em
-#' @template section_dictionary_learner
+#' @template learner
 #' @template example
 #'
 #' @export
@@ -20,21 +20,19 @@ LearnerClustEM = R6Class("LearnerClustEM",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ParamSet$new(
-        params = list(
-          ParamInt$new(id = "I", default = 100L, lower = 1L, tags = "train"),
-          ParamDbl$new(id = "ll_cv", default = 1e-6, lower = 1e-6, tags = "train"),
-          ParamDbl$new(id = "ll_iter", default = 1e-6, lower = 1e-6, tags = "train"),
-          ParamDbl$new(id = "M", default = 1e-6, lower = 1e-6, tags = "train"),
-          ParamInt$new(id = "max", default = -1L, lower = -1L, tags = "train"),
-          ParamInt$new(id = "N", default = -1L, lower = -1L, tags = "train"),
-          ParamInt$new(id = "num_slots", default = 1L, lower = 1L, tags = "train"),
-          ParamInt$new(id = "S", default = 100L, lower = 0L, tags = "train"),
-          ParamInt$new(id = "X", default = 10L, lower = 1L, tags = "train"),
-          ParamInt$new(id = "K", default = 10L, lower = 1L, tags = "train"),
-          ParamLgl$new(id = "V", default = FALSE, tags = "train"),
-          ParamLgl$new(id = "output_debug_info", default = FALSE, tags = "train")
-        )
+      ps = ps(
+        I = p_int(default = 100L, lower = 1L, tags = "train"),
+        ll_cv = p_dbl(default = 1e-6, lower = 1e-6, tags = "train"),
+        ll_iter = p_dbl(default = 1e-6, lower = 1e-6, tags = "train"),
+        M = p_dbl(default = 1e-6, lower = 1e-6, tags = "train"),
+        max = p_int(default = -1L, lower = -1L, tags = "train"),
+        N = p_int(default = -1L, lower = -1L, tags = "train"),
+        num_slots = p_int(default = 1L, lower = 1L, tags = "train"),
+        S = p_int(default = 100L, lower = 0L, tags = "train"),
+        X = p_int(default = 10L, lower = 1L, tags = "train"),
+        K = p_int(default = 10L, lower = 1L, tags = "train"),
+        V = p_lgl(default = FALSE, tags = "train"),
+        output_debug_info = p_lgl(default = FALSE, tags = "train")
       )
 
       super$initialize(
@@ -43,7 +41,8 @@ LearnerClustEM = R6Class("LearnerClustEM",
         predict_types = "partition",
         param_set = ps,
         properties = c("partitional", "exclusive", "complete"),
-        packages = "RWeka"
+        packages = "RWeka",
+        label = "Expectation-Maximization Clustering"
       )
     }
   ),
